.. _examples:

********
Examples
********

These examples can be found in the ``docs/examples`` directory. The examples
are Jupyter notebooks and if you would like to run them yourself, refer to
the `Jupyter documentation <https://jupyter-notebook.readthedocs.io/en/latest/>`_ for
instructions on how to install and run Jupyter.

If you would like to see KerasLMU used to solve the Permuted Sequential MNIST task,
which is the problem used in the
`original paper <https://papers.nips.cc/paper/9689-legendre-memory-units-continuous-time-representation-in-recurrent-neural-networks.pdf>`_,
you can look through the example below:

.. toctree::
   :maxdepth: 1

   examples/psMNIST

The LMU cell has also been implemented in other Nengo packages. You can find these
implementations by following the links below.

.. include:: ../README.rst
   :start-line: 30
   :end-line: 33
